==> OmegaT_2.0.5_04_Source.zip: src/org/omegat/filters3/xml/XMLUtils.java <==
/**************************************************************************
 OmegaT - Computer Assisted Translation (CAT) tool 
          with fuzzy matching, translation memory, keyword search, 
          glossaries, and translation leveraging into updated projects.

 Copyright (C) 2000-2006 Keith Godfrey and Maxym Mykhalchuk
               Home page: http://www.omegat.org/
               Support center: http://groups.yahoo.com/group/OmegaT/

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
**************************************************************************/

package org.omegat.filters3.xml;

import org.omegat.filters3.Attribute;
import org.omegat.filters3.Attributes;
import org.omegat.util.StaticUtils;

/**
 * Static XML utility methods.
 *
 * @author Maxym Mykhalchuk
 */
public final class XMLUtils
{
    
    /** Private to disallow creation. */
    private XMLUtils() {}
    
    /** Converts attributes from org.xml.sax package to OmegaT's. */
    public static Attributes convertAttributes(org.xml.sax.Attributes attributes)
    {
        Attributes res = new Attributes();
        if (attributes==null)
            return res;
        
        for (int i = 0; i < attributes.getLength(); i++)
        {
            String name = StaticUtils.makeValidXML(attributes.getQName(i));
            String value = StaticUtils.makeValidXML(attributes.getValue(i));
            Attribute attr = new Attribute(name, value);
            res.add(attr);
        }
        return res;
    }
    
}

==> OmegaT_2.6.3_01_Source.zip: src/org/omegat/filters3/xml/XMLUtils.java <==
/**************************************************************************
 OmegaT - Computer Assisted Translation (CAT) tool 
          with fuzzy matching, translation memory, keyword search, 
          glossaries, and translation leveraging into updated projects.

 Copyright (C) 2000-2006 Keith Godfrey and Maxym Mykhalchuk
               2010 Didier Briel
               Home page: http://www.omegat.org/
               Support center: http://groups.yahoo.com/group/OmegaT/

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 **************************************************************************/

package org.omegat.filters3.xml;

import org.omegat.filters3.Attribute;
import org.omegat.filters3.Attributes;
import org.omegat.util.StaticUtils;

/**
 * Static XML utility methods.
 * 
 * @author Maxym Mykhalchuk
 */
public final class XMLUtils {

    /** Private to disallow creation. */
    private XMLUtils() {
    }

    /** Converts attributes from org.xml.sax package to OmegaT's. */
    public static Attributes convertAttributes(org.xml.sax.Attributes attributes) {
        Attributes res = new Attributes();
        if (attributes == null)
            return res;

        for (int i = 0; i < attributes.getLength(); i++) {
            String name = StaticUtils.makeValidXML(attributes.getQName(i));
            String value = StaticUtils.makeValidXML(attributes.getValue(i));
            Attribute attr = new Attribute(name, value);
            res.add(attr);
        }
        return res;
    }

}
